import mdtraj as md
from tqdm import tqdm
import click
import numpy as np
import pickle



@click.command()
@click.argument('traj')
@click.argument('top')
@click.option('--output', default='contacts')
@click.option('--stride', default=10)
@click.option('--weights/--noweights', default=False)
@click.option('--cutoff', default=0.35)
def contacts(traj, top, output, stride, weights, cutoff):

    # load weights
    if weights:
        weights = np.loadtxt('weights.dat')
        # convert to probs
        weights = weights[:,1] - np.max(weights[:,1])
        kt = 2.494
        weights = np.exp(weights / kt)
        weights /= np.sum(weights)

        subsampled = md.load(traj, top=top, stride=stride)
        contacts = md.geometry.squareform(*md.compute_contacts(subsampled, contacts='all', scheme='sidechain-heavy'))        
        #mat = np.sum( (contacts < 0.35) * (contacts > 1e-5) * weights[:, np.newaxis, np.newaxis], axis=0)
        mat = contacts, weights
    else:
        subsampled = md.load(traj, top=top, stride=stride)
        contacts = md.geometry.squareform(*md.compute_contacts(subsampled, contacts='all', scheme='sidechain-heavy'))

        mat = contacts
    print(f'Complete, writing {output}')
    with open(f'{output}.pb', 'wb') as f:
        pickle.dump(mat, f)

if __name__ == '__main__':
    contacts()

