import mdtraj as md
from tqdm import tqdm
import click
import numpy as np
import pickle



@click.command()
@click.argument('traj')
@click.argument('top')
@click.argument('colvar')
@click.argument('traj_ts')
@click.argument('selection_file')
@click.argument('output')
@click.option('--output_top', default=None)
def traj(traj, top, colvar, traj_ts, selection_file, output, output_top):
    subsampled = md.load(traj, top=top)

    # get topology
    if output_top is None:
        top = subsampled.topology
    else:
        top = md.load(output_top).topology

    protein = subsampled.topology.select('protein')
    output_traj = md.Trajectory(
        xyz=np.empty((0, len(protein), 3)), 
        topology=top,
        unitcell_lengths=np.array([]).reshape((0,3)),
        unitcell_angles=np.array([]).reshape((0,3))
    )

    cv_data = np.loadtxt(colvar)
    cvs = np.loadtxt(selection_file)
    # find closest to values
    for i in range(cvs.shape[0]):
        # slice out time and get dist to selections
        j = np.argmin(np.sum((cv_data[:, 1:] - cvs[i])**2, axis=1))
        # now get from trajectory
        time = cv_data[j, 0]
        k = int(time // float(traj_ts))
        print(k)
        f = subsampled[k].restrict_atoms(protein)
        output_traj = output_traj.join(f, check_topology=False) 

    # molecules in good orientation
    output_traj.make_molecules_whole()

    output_traj.save(output)

if __name__ == '__main__':
    traj()

