import mdtraj as md
import numpy as np
import click

@click.command()
@click.argument('traj')
@click.argument('output_traj')
@click.option('--nrows', default=3)
@click.option('--margin', default=1.2)
@click.option('--ncols', default=3)
def layout(traj, output_traj, nrows, ncols, margin):
    traj = md.load(traj)
    traj.topology.create_standard_bonds()
    out = md.Trajectory(
        xyz=np.empty((0, traj.n_atoms, 3)), 
        topology=traj.topology,
        unitcell_lengths=np.array([]).reshape((0,3)),
        unitcell_angles=np.array([]).reshape((0,3))        
    )
    
    index = 0
    translation = np.zeros((3))
    for i in range(nrows):
        ymax = 0
        for j in range(ncols):
            if index == len(traj):
                break
            f = traj[index]
            print(translation, f.xyz[0,0])
            print(translation, f.xyz[0,0])
            fmin = np.amin(f.xyz[0], axis=0)
            fmax = np.amax(f.xyz[0], axis=0)
            f.xyz[0] -= fmin
            f.xyz += translation
            out = out.join(f)
            translation[0] += (fmax[0] - fmin[0]) * margin # only increment x
            ymax = max(fmax[1], ymax)
            index += 1
        translation[0] = 0
        translation[1] += ymax * margin

    
    out.save(f'{output_traj}')

if __name__ == '__main__':
    layout()
