import mdtraj as md
from tqdm import tqdm
import click
import numpy as np
import pickle
from sklearn.cluster import OPTICS



@click.command()
@click.argument('traj')
@click.argument('top')
@click.argument('output')
@click.option('--output_top', default=None)
@click.option('--stride', default=10)
def traj(traj, top, output, stride, output_top):
    subsampled = md.load(traj, top=top, stride=stride)
    selection = subsampled.topology.select('protein and name CA')
        
    # get topology
    if output_top is None:
        top = subsampled.topology
    else:
        top = md.load(output_top).topology


    protein = subsampled.topology.select('protein')
    output_traj = md.Trajectory(
        xyz=np.empty((0, len(protein), 3)), 
        topology=top,
        unitcell_lengths=np.array([]).reshape((0,3)),
        unitcell_angles=np.array([]).reshape((0,3))
    )
    
    for i in tqdm(range(len(subsampled))):
        f = subsampled[i].restrict_atoms(protein)
        output_traj = output_traj.join(f, check_topology=False) 


    # molecules in good orientation
    output_traj.make_molecules_whole()

    output_traj.save(output)

if __name__ == '__main__':
    traj()

