import mdtraj as md
from tqdm import tqdm
import click
import numpy as np
import pickle



@click.command()
@click.argument('traj')
@click.argument('top')
@click.option('--output', default='dssp.pdb')
@click.option('--stride', default=10)
def contacts(traj, top, output, stride):

    # load weights
    try:
        weights = np.loadtxt('weights.dat')
        # convert to probs
        weights = weights[:,1] - np.max(weights[:,1])
        kt = 2.494
        weights = np.exp(weights / kt)
        weights /= np.sum(weights)
    except FileNotFound as e: 
        weights = np.ones(1)
        

    subsampled = md.load(traj, top=top, stride=stride)
    
    dssp = md.compute_dssp(subsampled, simplified=True)
    mat = dssp, weights[::stride] / np.sum(weights[::stride])
    print(f'Complete, writing {output}')
    with open(f'{output}.pb', 'wb') as f:
        pickle.dump(mat, f)

if __name__ == '__main__':
    contacts()

