import numpy as np
from peptidesim import PeptideSim, utilities
import sys
import os
import sys
import gromacs
from shutil import copyfile, move
import fire


def run(name, seq, peptide_copies, peptide_density, debug=False, temperature=300):
    ps = PeptideSim(name, seq, peptide_copies, job_name='{}'.format(name))
    ps.mdrun_driver = 'gmx_mpi'
    ps.mpi_np = 2
    ps.mpiexec = 'mpiexec'
    ps.run_kwargs = {'ntomp': 4}
    ps.forcefield = 'charmm27'
    ps.water = 'tip3p'
    ps.peptide_density = peptide_density  # mg/ml
    ps.ion_concentration = 0.01  # PBS
    # add terminal amidation, acetylation
    chain_count = sum(peptide_copies)
    ps.initialize(amidate=True, acetylate=True)

    def ns_ts(ns, scale=None):
        '''nano seconds to timesteps. Use scale to turn down times for debugging'''
        if scale is None and debug:
            scale = 0.001
        else:
            scale = 1.0
        return str(max(1000, int(ns * 10**3 * 10**3 / 2 * scale)))


    ps.run(mdpfile='peptidesim_anneal.mdp', tag='annealing', mdp_kwargs={'nsteps': ns_ts(0.5)})
    ps.run(mdpfile='peptidesim_npt.mdp', tag='equil_npt', mdp_kwargs={'nsteps': ns_ts(2), 'ref_t': temperature})

    ps.mpi_np = None

    metad_file = '''

    MOLINFO MOLTYPE=protein STRUCTURE=../prep/dry_mixed.pdb
    c1: GROUP ATOMS={@mdt:{protein and (backbone and chainid 0)}}
    c2: GROUP ATOMS={@mdt:{protein and (backbone and chainid 0)}}
    c3: GROUP ATOMS={@mdt:{protein and (backbone and chainid 0)}}
    c4: GROUP ATOMS={@mdt:{protein and (backbone and chainid 0)}}    


    '''


    ps.run(mdpfile='peptidesim_nvt.mdp',
           tag='nvt-production',
           mdp_kwargs={'nsteps': ns_ts(1000), 'ref_t': temperature, 'nstfout': 0, 'nstxout': 2000})

if __name__ == '__main__':
    fire.Fire(run)
